@@ -4,19 +4,6 @@
 #include "output.h"
 
 int SWFFilter_testBlockType(int type);
-/* {
-	switch(type)
-	{
-		case SWF_DEFINEBUTTON:
-		case SWF_DEFINEBUTTON2:
-		case SWF_DEFINESPRITE:
-		case SWF_DEFINETEXT:
-		case SWF_DEFINETEXT2:
-			return 1;
-		default: return 0;
-	}
-} */
-/* Commented by Yixuan Qiu */
 
 void
 SWFOutput_writeSWFFilter(SWFOutput out, SWFFilter filter);
